@@ -6,32 +6,31 @@
 - MagSystems
 """
 
-import string
-import tarfile
-import warnings
 import os
+import warnings
 from os.path import join
-import codecs
-from collections import OrderedDict
 
 import numpy as np
-from astropy import wcs, units as u
-from astropy.io import ascii, fits
-from astropy.config import ConfigItem, get_cache_dir
+from astropy import units as u, wcs
+from astropy.config import get_cache_dir
+from astropy.io import fits
 from astropy.utils.data import get_pkg_data_filename
 
+from . import conf
 from . import io
 from . import snfitio
-from .utils import download_file, download_dir, DataMirror
-from .models import (Source, TimeSeriesSource, SALT2Source, MLCS2k2Source,
-                     SNEMOSource, _SOURCES)
-from .bandpasses import (Bandpass, read_bandpass, _BANDPASSES,
-                         _BANDPASS_INTERPOLATORS)
-from .spectrum import Spectrum
-from .magsystems import (MagSystem, SpectralMagSystem, ABMagSystem,
-                         CompositeMagSystem, _MAGSYSTEMS)
-from . import conf
+from .bandpasses import (
+    Bandpass, _BANDPASSES, _BANDPASS_INTERPOLATORS, read_bandpass)
+
 from .constants import BANDPASS_TRIM_LEVEL
+from .magsystems import (
+    ABMagSystem, CompositeMagSystem, SpectralMagSystem, _MAGSYSTEMS)
+
+from .models import (
+    MLCS2k2Source, SALT2Source, SNEMOSource, TimeSeriesSource, _SOURCES)
+
+from .spectrum import Spectrum
+from .utils import DataMirror
 
 # This module is only imported for its side effects.
 __all__ = []
@@ -402,10 +401,25 @@ for name, fname in [('4shooter2::us', 'bandpasses/4shooter2/Us_4Shooter2.txt'),
                     ('4shooter2::v', 'bandpasses/4shooter2/V_4Shooter2.txt'),
                     ('4shooter2::r', 'bandpasses/4shooter2/R_4Shooter2.txt'),
                     ('4shooter2::i', 'bandpasses/4shooter2/I_4Shooter2.txt')]:
+
     _BANDPASSES.register_loader(name, load_bandpass_remote_aa,
                                 args=(fname,), meta=fourshooter_meta)
+
+
+# ZTF
+ztf_meta = {
+    'filterset': 'ztf',
+    'retrieved': '7 Jun 2018',
+    'description': 'ZTF filters from Uli Feindt. No atmospheric correction.'}
+for name, fname in [('ztfg', 'bandpasses/ztf/P48_g.dat'),
+                    ('ztfr', 'bandpasses/ztf/P48_R.dat'),
+                    ('ztfi', 'bandpasses/ztf/P48_I.dat')]:
+    _BANDPASSES.register_loader(name, load_bandpass_remote_aa,
+                                args=(fname,),
+                                meta=ztf_meta)
+
 # =============================================================================
-# bandpass interpolators
+# interpolators
 
 megacam_meta = {'filterset': 'megacampsf'}
 
